@@ -312,7 +312,7 @@ objectValueForTableColumn: (NSTableColumn *)tc
 
   NSArray *list = [classManager allClassNames];
   NSString *superClass = [classManager parentOfClass: [self _currentClass]];
-  int index = [list indexOfObject: superClass];
+  NSUInteger index = [list indexOfObject: superClass];
 
   [classField setStringValue: [self _currentClass]];
   [outletTable reloadData];
@@ -531,25 +531,40 @@ objectValueForTableColumn: (NSTableColumn *)tc
 	{
 	  NSString *newParent = [list objectAtIndex: row];
 	  NSString *name = [self _currentClass];
-	  BOOL removed = NO;
 	  GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
 	  
 	  // if it's a custom class, let it go, if not do nothing.
 	  if(document != nil)
 	    {
 	      if([classManager isCustomClass: name])
-		{     
+		{
+		  NSString *title = [NSString stringWithFormat: _(@"Modifying/Reparenting Class")];
+		  NSString *msg = [NSString stringWithFormat: _(@"This action may break existing connections "
+								@"to instances of class '%@'"
+								@"and it's subclasses.  Continue?"), name];
+		  int retval = -1;
+		  BOOL removed = NO;
+
 		  [super ok: sender];
 		  
-		  // check to see if the user wants to do this and remove the connections.
-		  removed = [document removeConnectionsForClassNamed: name]; 
-		  
+		  // ask the user if he/she wants to continue...
+		  retval = NSRunAlertPanel(title, msg,_(@"OK"),_(@"Cancel"), nil, nil);
+		  if (retval == NSAlertDefaultReturn)
+		    {
+		      removed = YES;
+		    }
+		  else
+		    {
+		      removed = NO;
+		    }
+
 		  // if removed, move the class and notify... 
 		  if(removed)
 		    {
 		      NSString *oldSuper = [classManager superClassNameForClassNamed: name];
 		      
 		      [classManager setSuperClassNamed: newParent forClassNamed: name];
+		      [document refreshConnectionsForClassNamed: name];
 		      [nc postNotificationName: IBInspectorDidModifyObjectNotification
 			  object: classManager];
 		      [document collapseClass: oldSuper];
@@ -573,12 +588,13 @@ objectValueForTableColumn: (NSTableColumn *)tc
   NSString *name = [self _currentClass];
   NSString *newName = [sender stringValue];
   GormDocument *document = (GormDocument *)[(id <IB>)NSApp activeDocument];
-  BOOL removed = NO;
+  BOOL flag = NO;
 
-  // check to see if the user wants to do this and remove the connections.
-  removed = [document removeConnectionsForClassNamed: name]; 
+  // check to see if the user wants to do this and rename the connections.
+  flag = [document renameConnectionsForClassNamed: name
+		   toName: newName]; 
 
-  if(removed)
+  if(flag)
     {
       [document collapseClass: name];
       [classManager renameClassNamed: name
