@@ -30,7 +30,6 @@
 #include "GormPalettesManager.h"
 #include <InterfaceBuilder/IBEditors.h>
 #include <InterfaceBuilder/IBPalette.h>
-#include <GNUstepBase/GSCategories.h>
 #include <Foundation/NSValue.h>
 #include <Foundation/NSException.h>
 
@@ -691,7 +690,7 @@
     }
 
   actions = [self allActionsForClassNamed: className];
-  while (actions == nil && (theClass = class_get_super_class(theClass)) != nil
+  while (actions == nil && (theClass = class_getSuperclass(theClass)) != nil
     && theClass != [NSObject class])
     {
       className = NSStringFromClass(theClass);
@@ -814,7 +813,7 @@
     }
 
   outlets = [self allOutletsForClassNamed: className];
-  while (outlets == nil && (theClass = class_get_super_class(theClass)) != nil
+  while (outlets == nil && (theClass = class_getSuperclass(theClass)) != nil
     && theClass != [NSObject class])
     {
       className = NSStringFromClass(theClass);
@@ -886,7 +885,7 @@
 
       if (theClass != nil)
 	{
-	  theClass = class_get_super_class(theClass);
+	  theClass = class_getSuperclass(theClass);
 	  if (theClass != nil && theClass != [NSObject class])
 	    {
 	      NSString			*name;
@@ -1503,6 +1502,12 @@
   BOOL result = NO;
   id cls = nil;
 
+  // If there are no classes to add, return gracefully.
+  if([classes count] == 0)
+    {
+      return YES;
+    }
+
   while((cls = [en nextObject]) != nil)
     {
       NSString *className = [cls objectForKey: @"CLASS"];
@@ -1846,8 +1851,17 @@
     [NSString defaultCStringEncoding]];
 
   [headerData writeToFile: headerPath atomically: NO];
+
+  [[NSDistributedNotificationCenter defaultCenter]
+    postNotificationName: @"GormCreateFileNotification"
+    object: headerPath];
+
   [sourceData writeToFile: sourcePath atomically: NO];
 
+  [[NSDistributedNotificationCenter defaultCenter]
+    postNotificationName: @"GormCreateFileNotification"
+    object: sourcePath];
+
   return YES;
 }
 
@@ -1915,6 +1929,9 @@
 			  GormFilesOwner *owner = [document objectForName: @"NSOwner"];
 			  NSString *ownerClassName = [owner className];
 
+			  // Retain this, in case we're dealing with the NSOwner...
+			  RETAIN(ownerClassName);
+
 			  // delete the class..
 			  [self removeClassNamed: className];
 			  
@@ -1924,11 +1941,17 @@
 				withActions: actions
 				withOutlets: outlets];
 			  
+			  // Set the owner back to the class name, if needed.
+			  if([className isEqualToString: ownerClassName])
+			    {
+			      [owner setClassName: className];
+			    }
+			  
 			  // refresh the connections.
 			  [document refreshConnectionsForClassNamed: className];
-
-			  // reset the class name.
-			  [owner setClassName: ownerClassName];
+			  
+			  // Release the owner classname...
+			  RELEASE(ownerClassName);
 			}
 		    }
 		  else
