@@ -41,6 +41,7 @@
 #include <AppKit/NSSound.h>
 #include <AppKit/NSNibConnector.h>
 #include <AppKit/NSNibLoading.h>
+#include <AppKit/NSScreen.h>
 #include <GNUstepGUI/GSGormLoading.h>
 #include "NSView+GormExtensions.h"
 #include "GormSound.h"
@@ -440,10 +441,10 @@ static NSImage  *fileImage = nil;
     {
       NSRect frame = [window frame];
       NSPoint origin = frame.origin;
-      NSRect menuFrame = [[mainMenu window] frame];
+      NSRect screen = [[NSScreen mainScreen] frame];
       
       // account for the height of the menu we're loading.
-      origin.y += (frame.size.height + menuFrame.size.height + 150);
+      origin.y = (screen.size.height - 100);
       
       // place the main menu appropriately...
       [[mainMenu window] setFrameTopLeftPoint: origin];
@@ -563,6 +564,9 @@ static NSImage  *fileImage = nil;
   NSArray *old;
   BOOL newObject = NO;
 
+  // Modify the document whenever something is added...
+  [self touch];
+
   /*
    * Create a connector that links this object to its parent.
    * A nil parent is the root of the hierarchy so we use a dummy object for it.
@@ -707,6 +711,17 @@ static NSImage  *fileImage = nil;
 	    {
 	      [self setWindowsMenu: menu];
 	    }
+	  else if([[menu title] isEqual: @"Open Recent"] && [self recentDocumentsMenu] == nil)
+	    {
+	      [self setRecentDocumentsMenu: menu];
+	    }
+	  // if it doesn't have a supermenu and it's owned by the file's owner, then it's a top level menu....
+	  else if([menu supermenu] == nil && aParent == filesOwner)
+	    {
+	      [objectsView addObject: menu];
+	      [topLevelObjects addObject: menu];
+	      isMainMenu = NO;
+	    }
 	}
 
       // add all of the items in the menu.
@@ -723,8 +738,9 @@ static NSImage  *fileImage = nil;
 	{
 	  NSRect frame = [[self window] frame];
 	  NSPoint origin = frame.origin;
+	  NSRect screen = [[NSScreen mainScreen] frame];
 
-	  origin.y += (frame.size.height + 150);
+	  origin.y = (screen.size.height - 100);
 
 	  // Place the main menu appropriately...
 	  [[menu window] setFrameTopLeftPoint: origin];
@@ -1335,6 +1351,10 @@ static NSImage  *fileImage = nil;
 	    {
 	      [self setServicesMenu: nil];
 	    }
+	  else if([self recentDocumentsMenu] == anObject)
+	    {
+	      [self setRecentDocumentsMenu: nil];
+	    }
 	}
       
       /*
@@ -1389,6 +1409,7 @@ static NSImage  *fileImage = nil;
 
       [self setSelectionFromEditor: nil]; // clear the selection.
       RELEASE(name); // retained at beginning of method...
+      [self touch]; // set the document as modified
     }
 }
 
@@ -2191,6 +2212,9 @@ static void _real_close(GormDocument *self,
     {
       RELEASE(oldName);
     }
+
+  // touch the document...
+  [self touch];
 }
 
 /**
@@ -2287,6 +2311,29 @@ static void _real_close(GormDocument *self,
   return [nameTable objectForKey: @"NSServicesMenu"];
 }
 
+/**
+ * Set the menu that will be the recent documents menu in the app.
+ */
+- (void) setRecentDocumentsMenu: (NSMenu *)anObject 
+{
+  if(anObject != nil)
+    {
+      [nameTable setObject: anObject forKey: @"NSRecentDocumentsMenu"];
+    }
+  else
+    {
+      [nameTable removeObjectForKey: @"NSRecentDocumentsMenu"];
+    }
+}
+
+/**
+ * Return the object that will be the receent documents menu.
+ */ 
+- (NSMenu *) recentDocumentsMenu
+{
+  return [nameTable objectForKey: @"NSRecentDocumentsMenu"];
+}
+
 /**
  * Marks this document as the currently active document.  The active document is
  * the one being edited by the user.
@@ -2467,6 +2514,21 @@ static void _real_close(GormDocument *self,
     }
   else if([object isKindOfClass: [NSCell class]])
     {
+      NSCell *cell = object;
+      NSView *control = [cell controlView];
+
+      if ([control isKindOfClass: [NSMatrix class]])
+        {
+          int row, col;
+          NSMatrix *matrix = (NSMatrix *)control;
+
+          if ([matrix getRow: &row column: &col ofCell: cell])
+            {
+              NSRect cellFrame = [matrix cellFrameAtRow: row column: col];
+              *r = [control convertRect: cellFrame toView: nil];
+              return [control window];
+            }
+        }
     }
 
   // if we get here, then it wasn't any of the above.
@@ -3298,6 +3360,10 @@ static void _real_close(GormDocument *self,
       [[NSNotificationCenter defaultCenter]
 	postNotificationName: IBDidOpenDocumentNotification
 	object: self];
+
+      // make sure that the newly loaded document does not 
+      // mark itself as modified.
+      [self updateChangeCount: NSChangeCleared];
     }
   
   return result;
