@@ -38,7 +38,7 @@ static NSMapTable *docMap = 0;
   if (self == [GormImageEditor class])
     {
       docMap = NSCreateMapTable(NSNonRetainedObjectMapKeyCallBacks,
-				NSObjectMapValueCallBacks, 2);
+				NSNonRetainedObjectMapValueCallBacks, 2);
     }
 }
 
@@ -126,8 +126,16 @@ static NSMapTable *docMap = 0;
   // Once loaded, they are in the cache permanently and
   // are release on app termination.
 
-  RELEASE(objects);
-  NSDebugLog(@"Released...");
+  // RELEASE(objects);
+  NSDebugLog(@"Released image editor...");
+  // GSNOSUPERDEALLOC;
+  [super dealloc];
+}
+
+- (void) willCloseDocument: (NSNotification *)aNotification
+{
+  NSMapRemove(docMap,document);
+  [super willCloseDocument: aNotification];
 }
 
 - (void) close
