@@ -28,6 +28,7 @@
 #include <InterfaceBuilder/IBInspectorMode.h>
 #include <InterfaceBuilder/IBObjectAdditions.h>
 #include <InterfaceBuilder/IBInspectorManager.h>
+#include <InterfaceBuilder/IBDocuments.h>
 #include "GormPrivate.h"
 #include "GormImage.h"
 #include "GormSound.h"
@@ -273,6 +274,7 @@
   NSArray	*selection = [[(id<IB>)NSApp selectionOwner] selection];
   unsigned	count = [selection count];
   id		obj = [selection lastObject];
+  id<IBDocuments> document = [(id<IB>)NSApp activeDocument];
   NSView	*newView = nil;
   NSView	*oldView = nil;
   NSString	*newInspector = nil;
@@ -340,8 +342,9 @@
     }
   else
     {
-      NSString *newTitle = [selectedObject objectNameForInspectorTitle]; 
-      [panel setTitle: [NSString stringWithFormat:_(@"%@ Inspector"), newTitle]];
+      NSString *newTitle = [selectedObject objectNameForInspectorTitle];
+      NSString *objName = [document nameForObject: selectedObject];
+      [panel setTitle: [NSString stringWithFormat:_(@"%@ (%@) Inspector"), newTitle,objName]];
     }
 
   if (newInspector == nil)
@@ -385,7 +388,7 @@
 
       oldView = [inspectorView contentView];
       newView = [[inspector window] contentView];
-      if (newView != nil)
+      if (newView != nil && newView != oldView)
 	{   
 	  id initialResponder = [[inspector window] initialFirstResponder];
 	  NSView	*outer = [panel contentView];
@@ -452,7 +455,7 @@
 	  RETAIN(oldView);
 	  [inspectorView setContentView: newView];
 	  [[prevInspector window] setContentView: oldView];
-	  RELEASE(oldView);
+	  // RELEASE(oldView);
 
 	  /* Set the default First responder to the new View */
 	  if ( initialResponder )
