@@ -24,44 +24,33 @@
 
 #include <InterfaceBuilder/IBObjectAdditions.h>
 #include <AppKit/AppKit.h>
-
 #include "GormPrivate.h"
 #include "GormInternalViewEditor.h"
 #include "GormFontViewController.h"
-
 #include "GormViewKnobs.h"
+#include "GormDefines.h"
 
 @class GormEditorToParent;
 
 static NSImage *verticalImage;
 static NSImage *horizontalImage;
 
-#ifndef max
-#define max(a,b) ((a) >= (b) ? (a):(b))
-#endif
-
-#ifndef min
-#define min(a,b) ((a) <= (b) ? (a):(b))
-#endif
-
-
 @implementation NSView (IBObjectAdditions)
 - (NSString*) editorClassName
 {
   // using NSBox gets rid of compiler warning, should be safe for all classes. 
-  if ([self superview] && 
-      (([[self superview] respondsToSelector: @selector(contentView)] &&
-	[(NSBox *)[self superview] contentView] == self) 
-       ||
-       [[self superview] isKindOfClass: [NSTabView class]]
-       || 
-       [[[self superview] window] contentView] == self 
-       ||
-       [[self superview] isKindOfClass: [NSClipView class]]
-       ))
+  if ([self superview] && (([[self superview] respondsToSelector: @selector(contentView)] &&
+			    [(NSBox *)[self superview] contentView] == self) ||
+			   [[self superview] isKindOfClass: [NSTabView class]] || 
+			   [[[self superview] window] contentView] == self ||
+			   [[self superview] isKindOfClass: [NSClipView class]]))
     {
       return @"GormInternalViewEditor";
     }
+  else if ([self class] == [NSView class])
+    {
+      return @"GormStandaloneViewEditor";
+    } 
   else
     {
       return @"GormViewWithSubviewsEditor";
