@@ -583,35 +583,53 @@ static BOOL done_editing;
       int newRows = (frame.size.height - [_EO frame].size.height) /
 	heightIncrement;
       
-      int i;
+      int i, j;
 
       if (newCols > 0)
 	{
-	  for ( i = 0; i < newCols; i++)
+	  for (j = cols; j < cols + newCols; j++)
 	    {
 	      [_EO addColumn];
+	      for (i = 0; i < rows; i++)
+		{
+		  [document attachObject: [_EO cellAtRow: i column: j]
+				toParent: _EO];
+		}
 	    }
 	}
       else if (newCols < 0)
 	{
-	  for ( i = 0; i < -newCols; i++)
+	  for (j = cols - 1; j >= cols - newCols; j--)
 	    {
-	      [_EO removeColumn: cols - i - 1];
+	      for (i = 0; i < rows; i++)
+		{
+		  [document detachObject: [_EO cellAtRow: i column: j]];
+		}
+	      [_EO removeColumn: j];
 	    }
 	}
 
       if (newRows > 0)
 	{
-	  for ( i = 0; i < newRows; i++)
+	  for (i = rows; i < rows + newRows; i++)
 	    {
 	      [_EO addRow];
+	      for (j = 0; j < cols + newCols; j++)
+		{
+		  [document attachObject: [_EO cellAtRow: i column: j]
+				toParent: _EO];
+		}
 	    }
 	}
       else if (newRows < 0)
 	{
-	  for ( i = 0; i < -newRows; i++)
+	  for (i = rows - 1; i >= rows + newRows; i--)
 	    {
-	      [_EO removeRow: rows - i - 1];
+	      for (j = 0; j < cols + newCols; j++)
+		{
+		  [document detachObject: [_EO cellAtRow: i column: j]];
+		}
+	      [_EO removeRow: i];
 	    }
 	}
       [_EO setFrame: frame];
@@ -686,13 +704,56 @@ static BOOL done_editing;
   return;
 }
 
+- (id) connectTargetAtPoint: (NSPoint)mouseLoc
+{
+  int row, col;
+
+  if ([_EO getRow: &row column: &col forPoint: mouseLoc] == YES)
+    {
+      /* If a matrix has small intercell spacing (less than 1 pixel), it
+	 becomes impossible to make connections to the whole matrix, since
+	 -getRow:column:forPoint: returns YES for every location within the
+	 matrix's bounds. Therefore, we accept connection to matrix cells
+	 only if the mouse is strictly inside the cell. */
+      NSRect cellFrame = [_EO cellFrameAtRow: row column: col];
+
+      if (mouseLoc.x != NSMinX(cellFrame) &&
+	  mouseLoc.x != NSMaxX(cellFrame) &&
+	  mouseLoc.y != NSMinY(cellFrame) &&
+	  mouseLoc.y != NSMaxY(cellFrame))
+	{
+	  return [_EO cellAtRow: row column: col];
+	}
+    }
+
+  return _EO;
+}
+
+- (NSDragOperation) draggingEntered: (id<NSDraggingInfo>)sender
+{
+  NSPasteboard *dragPb;
+  NSArray      *types;
+
+  dragPb = [sender draggingPasteboard];
+  types = [dragPb types];
+  if ([types containsObject: GormLinkPboardType] == YES)
+    {
+      NSPoint loc = [sender draggingLocation];
+      NSPoint mouseDownPoint = [_EO convertPoint: loc fromView: nil];
+
+      [NSApp displayConnectionBetween: [NSApp connectSource]
+	     and: [self connectTargetAtPoint: mouseDownPoint]];
+      return NSDragOperationLink;
+    }
+  return [super draggingEntered: sender];
+}
+
 - (BOOL) performDragOperation: (id<NSDraggingInfo>)sender
 {
   NSPasteboard	*dragPb;
   NSArray	*types;
   NSPoint       dropPoint = [sender draggedImageLocation];
-  NSPoint       mouseDownPoint = 
-    [_EO convertPoint: dropPoint fromView: nil];
+  NSPoint       mouseDownPoint = [_EO convertPoint: dropPoint fromView: nil];
 
   dragPb = [sender draggingPasteboard];
   types = [dragPb types];
@@ -700,14 +761,14 @@ static BOOL done_editing;
   if ([types containsObject: GormLinkPboardType])
     {
       [NSApp displayConnectionBetween: [NSApp connectSource] 
-	     and: _EO];
+             and: [self connectTargetAtPoint: mouseDownPoint]];
       [NSApp startConnecting];
     }
-  else if([types containsObject: GormImagePboardType] == YES ||
-	  [types containsObject: GormSoundPboardType] == YES)
+  else if ([types containsObject: GormImagePboardType] == YES ||
+	   [types containsObject: GormSoundPboardType] == YES)
     {
       int row, col;
-      if([_EO getRow: &row column: &col forPoint: mouseDownPoint] == YES)
+      if ([_EO getRow: &row column: &col forPoint: mouseDownPoint] == YES)
 	{
 	  id object = [_EO cellAtRow: row column: col];
 	  if ([types containsObject: GormImagePboardType] == YES)
@@ -715,7 +776,7 @@ static BOOL done_editing;
 	      NSString *name = [dragPb stringForType: GormImagePboardType];
 	      NSImage *image = [NSImage imageNamed: name];
 	      [image setArchiveByName: NO];
-	      if([object respondsToSelector: @selector(setSound:)])
+	      if ([object respondsToSelector: @selector(setSound:)])
 		{
 		  [object setImage: image];
 		}
@@ -726,11 +787,11 @@ static BOOL done_editing;
 
 	      return YES;
 	    }
-	  else if([types containsObject: GormSoundPboardType] == YES)
+	  else if ([types containsObject: GormSoundPboardType] == YES)
 	    {
 	      NSString *name;
 	      name = [dragPb stringForType: GormSoundPboardType];
-	      if([object respondsToSelector: @selector(setSound:)])
+	      if ([object respondsToSelector: @selector(setSound:)])
 		{
 		  [object setSound: [NSSound soundNamed: name]];
 		}
