@@ -38,14 +38,16 @@
 @end
 
 @implementation	GormPalettePanel
+/*
 - (BOOL) canBecomeKeyWindow
 {
   return NO;
 }
 - (BOOL) canBecomeMainWindow
 {
-  return NO;
+  return YES;
 }
+*/
 @end
 
 @interface GormPaletteView : NSView
@@ -84,6 +86,9 @@ static NSImage	*dragImage = nil;
 	IBCellPboardType, IBMenuPboardType, IBMenuCellPboardType,
 	IBObjectPboardType, IBViewPboardType, IBWindowPboardType,
         IBFormatterPboardType,nil]];
+
+      [self setAutoresizingMask: 
+	      NSViewMinXMargin|NSViewMinYMargin|NSViewMaxXMargin|NSViewMaxYMargin];
     }
   return self;
 }
@@ -113,10 +118,11 @@ static NSImage	*dragImage = nil;
 
       if (active != nil)
 	{
+          /*
 	  if([active objectForName: @"NSMenu"] != nil && 
 	     [type isEqual: IBMenuPboardType] == YES)
 	    return;
-
+	  */
 	  [active pasteType: type fromPasteboard: dragPb parent: nil];
 	}
     }
