@@ -38,7 +38,7 @@ static NSMapTable *docMap = 0;
   if (self == [GormSoundEditor class])
     {
       docMap = NSCreateMapTable(NSNonRetainedObjectMapKeyCallBacks,
-				NSObjectMapValueCallBacks, 2);
+				NSNonRetainedObjectMapValueCallBacks, 2);
     }
 }
 
@@ -116,6 +116,12 @@ static NSMapTable *docMap = 0;
   return self;
 }
 
+- (void) willCloseDocument: (NSNotification *)aNotification
+{
+  NSMapRemove(docMap,document);
+  [super willCloseDocument: aNotification];
+}
+
 - (void) close
 {
   [super close];
