@@ -31,18 +31,12 @@
 @interface GormViewWithContentViewEditor : GormViewWithSubviewsEditor
 {
   GormInternalViewEditor *contentViewEditor;
-  BOOL _followGuideLine;
 }
 
-- (void) handleMouseOnKnob: (IBKnobPosition) knob
-		    ofView: (GormViewEditor *) view
-		 withEvent: (NSEvent *) theEvent;
-
-- (void) handleMouseOnView: (GormViewEditor *) view
-		 withEvent: (NSEvent *) theEvent;
 - (void) postDrawForView: (GormViewEditor *) viewEditor;
 - (void) groupSelectionInSplitView;
 - (void) groupSelectionInBox;
+- (void) groupSelectionInView;
 - (void) ungroup;
 - (void) pasteInView: (NSView *)view;
 @end
