@@ -168,6 +168,15 @@
   [m addItemWithTitle: @"Open..." 
 	       action: @selector(openDocument:)
 	keyEquivalent: @"o"];
+  i = (NSMenuItem *)[m addItemWithTitle: @"Open Recent"
+				 action: NULL
+			  keyEquivalent: @""];
+  s = [[GormNSMenu alloc] init];
+  [s addItemWithTitle: @"Clear List"
+	       action: @selector(clearRecentDocuments:)
+	keyEquivalent: @""];
+  [s setTitle: @"Open Recent"];
+  [i setSubmenu: s];
   [m addItemWithTitle: @"New" 
 	       action: @selector(newDocument:)
 	keyEquivalent: @"n"];
@@ -255,6 +264,12 @@
    * The Edit menu
    */
   m = [[GormNSMenu alloc] init];
+  [m addItemWithTitle: @"Undo" 
+	       action: @selector(undo:) 
+	keyEquivalent: @"z"];
+  [m addItemWithTitle: @"Redo" 
+	       action: @selector(redo:) 
+	keyEquivalent: @"Z"];
   [m addItemWithTitle: @"Cut" 
 	       action: @selector(cut:) 
 	keyEquivalent: @"x"];
@@ -291,20 +306,24 @@
    * The Find menu
    */
   m = [[GormNSMenu alloc] init];
-  [m addItemWithTitle: @"Find Panel..." 
-	       action: NULL
-	keyEquivalent: @"f"];
-  [m addItemWithTitle: @"Find Next" 
-	       action: NULL
-	keyEquivalent: @"g"];
-  [m addItemWithTitle: @"Find Previous" 
-	       action: NULL
-	keyEquivalent: @"d"];
-  [m addItemWithTitle: @"Enter Selection" 
-	       action: NULL
-	keyEquivalent: @"e"];
+  i = [m addItemWithTitle: @"Find Panel..." 
+		   action: @selector(performFindPanelAction:)
+	    keyEquivalent: @"f"];
+  [i setTag: NSFindPanelActionShowFindPanel];
+  i = [m addItemWithTitle: @"Find Next" 
+		   action: @selector(performFindPanelAction:)
+	    keyEquivalent: @"g"];
+  [i setTag: NSFindPanelActionNext];
+  i = [m addItemWithTitle: @"Find Previous" 
+		   action: @selector(performFindPanelAction:)
+	    keyEquivalent: @"d"];
+  [i setTag: NSFindPanelActionPrevious];
+  i = [m addItemWithTitle: @"Enter Selection" 
+		   action: @selector(performFindPanelAction:)
+	    keyEquivalent: @"e"];
+  [i setTag: NSFindPanelActionSetFindString];
   [m addItemWithTitle: @"Jump To Selection" 
-	       action: NULL
+	       action: @selector(centerSelectionInVisibleArea:)
 	keyEquivalent: @"j"];
   [m setTitle: @"Find"];
   i = [[NSMenuItem alloc] initWithTitle: @"Find" 
