@@ -29,16 +29,17 @@
   Clean up
   Author : Fabien Vallon <fabien@sonappart.net>
 */
-#include "GormTableViewAttributesInspector.h"
-#include "GormNSTableView.h"
-#include <GormCore/NSColorWell+GormExtensions.h>
-#include <GormCore/GormPrivate.h>
-#include <Foundation/NSNotification.h>
-#include <AppKit/NSButton.h>
-#include <AppKit/NSColorWell.h>
-#include <AppKit/NSForm.h>
-#include <AppKit/NSMatrix.h>
-#include <AppKit/NSNibLoading.h>
+#import "GormTableViewAttributesInspector.h"
+#import "GormNSTableView.h"
+#import <GormCore/NSColorWell+GormExtensions.h>
+#import <GormCore/GormPrivate.h>
+#import <Foundation/NSNotification.h>
+#import <Foundation/NSSortDescriptor.h>
+#import <AppKit/NSButton.h>
+#import <AppKit/NSColorWell.h>
+#import <AppKit/NSForm.h>
+#import <AppKit/NSMatrix.h>
+#import <AppKit/NSNibLoading.h>
 
 
 @implementation GormTableViewAttributesInspector
@@ -235,7 +236,7 @@
 
   /* background color */
   [backgroundColor setColorWithoutAction: [object backgroundColor]];
-  
+
   [super revert:sender];
 }
 
