@@ -34,7 +34,7 @@
 #include "GormDateFormatterAttributesInspector.h"
 
 /* this macro makes sure that the string contains a value, even if @"" */
-#define VSTR(str) ({id _str = str; (_str) ? _str : @"";})
+#define VSTR(str) ({id _str = (id)str; (_str) ? (id)_str : (id)(@"");})
 
 extern NSArray *predefinedDateFormats;
 
