@@ -1,6 +1,4 @@
 /* GormNibWrapperLoader
- *
- * This class is a subclass of the NSDocumentController
  *
  * Copyright (C) 2006 Free Software Foundation, Inc.
  *
@@ -34,18 +32,10 @@
 #include <GormCore/NSView+GormExtensions.h>
 #include <GormCore/GormFunctions.h>
 #include <GormCore/GormCustomView.h>
+#include <GormCore/GormWindowTemplate.h>
 #include "GormNibWrapperLoader.h"
 
-@interface NSWindowTemplate (Private)
-- (void) setBaseWindowClass: (Class) clz;
-@end 
-
-@implementation NSWindowTemplate (Private)
-- (void) setBaseWindowClass: (Class) clz
-{
-  _baseWindowClass = clz;
-}
-@end
+@class GormNSWindow;
 
 @implementation GormNibWrapperLoader
 + (NSString *) fileType
@@ -138,6 +128,7 @@
 	       * handling class replacement so that standard objects understood
 	       * by the gui library are converted to their Gorm internal equivalents.
 	       */
+
 	      u = [[NSKeyedUnarchiver alloc] initForReadingWithData: data];
 	      [u setDelegate: self];
 	      
@@ -148,6 +139,10 @@
 		 forClassName: @"NSCustomObject"];
 	      [u setClass: [GormCustomView class] 
 		 forClassName: @"NSCustomView"];
+	      [u setClass: [GormWindowTemplate class] 
+		 forClassName: @"NSWindowTemplate"];
+	      [u setClass: [GormNSWindow class] 
+		 forClassName: @"NSWindow"];
 	      
 	      /*
 	       * Substitute any classes specified by the palettes...
@@ -326,6 +321,7 @@
 		  result = YES;
 		}
 	    }
+	  [NSClassSwapper setIsInInterfaceBuilder: NO];      
 	}
     }
   NS_HANDLER
